# Reference

Complete API documentation and lookup tables.

## Input and Modalities

- **[Input Formats](input-formats.md)** — Text, images, PDFs, templates

## Optimization

- **[Optimizers](optimizers.md)** — DSPy optimizer types and selection
- **[Evaluator Selection](evaluator-selection.md)** — Evaluator comparison tables

## API Documentation

- **[Prompter](api/prompter.md)** — Main API class
- **[Types](api/types.md)** — Core data types
- **[Extractor](api/extractor.md)** — Field extraction utilities
- **[Evaluators](api/evaluators.md)** — Evaluator classes

## Other Resources

- **Changelog** — [View releases](https://github.com/davidberenstein1957/dspydantic/releases)

## Using This Section

- **Looking for input format details?** → [Input Formats](input-formats.md)
- **Want to compare optimizers?** → [Optimizers](optimizers.md)
- **Need evaluator tables?** → [Evaluator Selection](evaluator-selection.md)
- **Looking for API signatures?** → [API Documentation](#api-documentation)
